@@ -5,7 +5,7 @@ use Carp;
 use Data::Dump qw( dump );
 use base qw( Search::Tools::Object );
 
-our $VERSION = '0.72';
+our $VERSION = '0.73';
 
 # debugging only
 my $OPEN  = '[';
@@ -141,7 +141,7 @@ sub _build {
 # currently _as_sentences() is mostly identical to _no_sentences()
 # with slightly fewer gymnastics.
 # Since we already know via sentence_starts where our boundaries are,
-# we not have to call $tokens->get_window().
+# we do not have to call $tokens->get_window().
 # Who knows how we might improve the sentence algorithm in future,
 # so already having it in its own method seems like a win.
 sub _as_sentences {
@@ -155,6 +155,19 @@ sub _as_sentences {
     my %heatmap         = ();
     my $token_list_heat = $tokens->get_heat;
     my $sentence_starts = $tokens->get_sentence_starts;
+
+    # this regex is a sanity check for phrases. we replace the \ with a
+    # more promiscuous check because the single space is too naive
+    # for real text (e.g. st. john's)
+    my $qre = $self->{_qre};
+    $qre =~ s/(\\ )+/.+/g;
+
+    if ( $self->debug ) {
+        warn "sentence_starts: " . dump($sentence_starts);
+        warn "token_list_heat: " . dump($token_list_heat);
+    }
+
+    # find the "sentence" that each hot token appears in.
     my @starts_ends;
     my $i = 0;
     for (@$token_list_heat) {
@@ -166,9 +179,17 @@ sub _as_sentences {
         my $max_end = $start + $sentence_length;
         $max_end = $num_tokens if $num_tokens < $max_end;
         while ( $end < $max_end ) {
-            my $tok = $tokens->get_token( $end++ ) or last;
+            my $tok = $tokens->get_token( $end++ );
+            if ( !$tok ) {
+                $self->debug and warn "No token at end=$end";
+                last;
+            }
             if ( $tok->is_sentence_end ) {
                 $end--;
+                if ( $self->debug ) {
+                    warn "tok $_ is_sentence_end end=$end";
+                    $tok->dump;
+                }
                 last;
             }
         }
@@ -179,11 +200,16 @@ sub _as_sentences {
         # if we didn't yet set the actual hot token,
         # include everything up to it.
         if ( $end < $token_pos ) {
+            $self->debug
+                and warn
+                "start=$start max_end=$max_end sentence_length=$sentence_length end=$end token_pos=$token_pos -- resetting end=$token_pos\n";
             $end = $token_pos;
         }
         push( @starts_ends, [ $start, $token_pos, $end ] );
     }
 
+    $self->debug and warn "starts_ends: " . dump( \@starts_ends );
+
     my @spans;
     my %seen_pos;
 START_END:
@@ -226,7 +252,10 @@ START_END:
         if ( !$self->{_treat_phrases_as_singles} ) {
 
             #warn "_treat_phrases_as_singles NOT true";
-            if ( $span{str} !~ m/$self->{_qre}/ ) {
+            if ( $span{str} !~ m/$qre/ ) {
+                $self->debug
+                    and warn
+                    "treat_phrases_as_singles=FALSE and $span{str} failed to match $qre\n";
                 next;
             }
         }
@@ -287,6 +316,12 @@ sub _no_sentences {
     my $lhs_window = int( $window / 2 );
     my $debug = $self->debug || 0;
 
+    # this regex is a sanity check for phrases. we replace the \ with a
+    # more promiscuous check because the single space is too naive
+    # for real text (e.g. st. john's)
+    my $qre = $self->{_qre};
+    $qre =~ s/(\\ )+/.+/g;
+
     # build heatmap
     my $num_tokens      = $tokens->len;
     my $tokens_arr      = $tokens->as_array;
@@ -387,7 +422,10 @@ CLUSTER:
         if ( !$self->{_treat_phrases_as_singles} ) {
 
             #warn "_treat_phrases_as_singles NOT true";
-            if ( $span{str} !~ m/$self->{_qre}/ ) {
+            if ( $span{str} !~ m/$qre/ ) {
+                $self->debug
+                    and warn
+                    "treat_phrases_as_singles=FALSE and $span{str} failed to match $qre\n";
                 next;
             }
         }
